#!/bin/sh
#----------------------------------------------------------------------------
# /var/install/config.d/cron-update.sh - update or generate new cron configuration
#
# Creation:     2005-05-21  max
# Last Update:  $Id: cron-update.sh 10552 2007-04-27 15:15:34Z hbfl $
#
# Copyright (c) 2001-2007  the eisfair team, team(at)eisfair(dot)org
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#----------------------------------------------------------------------------

# set packages name
packages_name='cron'

# include eislib
. /var/install/include/eislib

# include configib
. /var/install/include/configlib

#------------------------------------------------------------------------------
# set the default values for configuration
#------------------------------------------------------------------------------
START_CRON='yes'

CRON_N='1'

CRON_1_NAME=''
CRON_1_ACTIVE='yes'
CRON_1_TIMES='0 0 * * *'
CRON_1_COMMAND='/usr/sbin/logrotate /etc/logrotate.conf'

#------------------------------------------------------------------------------
# read old configuration
#------------------------------------------------------------------------------
rename_old_variables()
{
    # read old values
    test -f /etc/config.d/${packages_name} &&
        . /etc/config.d/${packages_name}

}
#------------------------------------------------------------------------------
# write config and default files
#------------------------------------------------------------------------------
make_config_file()
{
    internal_conf_file=${1}

    {
    #--------------------------------------------------------------------------------
    printgpl -conf ${packages_name} "2005-03-04" "max"
    #--------------------------------------------------------------------------------

    #--------------------------------------------------------------------------------
    printgroup "Cron Jobs"
    #--------------------------------------------------------------------------------

    printvar "START_CRON"       "start cron: yes or no"
    echo

    printvar "CRON_N"           "number of cron jobs to add"

    idx=1

    while [ ${idx} -le ${CRON_N} ]
    do

        eval active='${CRON_'${idx}'_ACTIVE}'

        case x${active} in
            x)
                eval CRON_${idx}_ACTIVE="yes"
            ;;

            x*)
                # nothing to do
            ;;
        esac

        echo
        printvar "CRON_${idx}_NAME" "Use a name what ever you want, it's only for you"
        printvar "CRON_${idx}_ACTIVE" "Use yes or no"
        printvar "CRON_${idx}_TIMES" "Cron configuration string"
        printvar "CRON_${idx}_COMMAND" "Command to start with cron"

        idx=`/usr/bin/expr ${idx} + 1`
    done
    #--------------------------------------------------------------------------------
    printend
    #--------------------------------------------------------------------------------

    } > ${internal_conf_file}
    # Set rights
    chmod 0600 ${internal_conf_file}
    chown root ${internal_conf_file}

}
#----------------------------------------------------------------------------
# create check.d file
#---------------------------------------------------------------------------
make_check_file()
{
printgpl -check ${packages_name} "2005-03-04" "max" >/etc/check.d/${packages_name}
cat >>/etc/check.d/${packages_name} <<EOF
# Variable          OPT_VARIABLE        VARIABLE_N    VALUE
START_CRON          -                   -             YESNO

CRON_N              START_CRON          -             NUMERIC
CRON_%_NAME         START_CRON          CRON_N        NONE
CRON_%_ACTIVE       START_CRON          CRON_N        YESNO
CRON_%_TIMES        CRON_%_ACTIVE       CRON_N        CRONTAB
CRON_%_COMMAND      CRON_%_ACTIVE       CRON_N        NONE

EOF

     # Set rights for check file
    chmod 0600 /etc/check.d/${packages_name}
    chown root /etc/check.d/${packages_name}
}
#------------------------------------------------------------------------------
# main
#------------------------------------------------------------------------------
# write default config file
test -f /etc/config.d/${packages_name} &&
    mecho -info -n "updating configuration ." ||
    mecho -info -n "creating configuration ."

make_config_file /etc/default.d/${packages_name}

# update from old version
mecho -info -n "."
rename_old_variables

# write new config file
mecho -info -n "."
make_config_file /etc/config.d/${packages_name}

# write check.d file
mecho -info -n "."
make_check_file

mecho -info ". finished"

exit 0
#------------------------------------------------------------------------------
# end
#------------------------------------------------------------------------------
